@@ -15,11 +15,13 @@ from draftsman.classes.mixins import (
     CircuitConnectableMixin,
     DirectionalMixin,
 )
-from draftsman.constants import InserterModeOfOperation
+from draftsman.error import DataFormatError
+from draftsman import signatures
 from draftsman.warning import DraftsmanWarning
 
 from draftsman.data.entities import filter_inserters
 
+from schema import SchemaError
 import six
 import warnings
 
@@ -37,8 +39,8 @@ class FilterInserter(
     Entity,
 ):
     """
-    An entity that can move items between machines, and has the ability to
-    ignore moving specific items.
+    An entity that can move items between machines, and has the ability to only
+    move specific items.
 
     .. NOTE::
 
@@ -66,6 +68,18 @@ class FilterInserter(
 
     # =========================================================================
 
+    @ControlBehaviorMixin.control_behavior.setter
+    def control_behavior(self, value):
+        # type: (dict) -> None
+        try:
+            self._control_behavior = (
+                signatures.FILTER_INSERTER_CONTROL_BEHAVIOR.validate(value)
+            )
+        except SchemaError as e:
+            six.raise_from(DataFormatError(e), None)
+
+    # =========================================================================
+
     @property
     def filter_mode(self):
         # type: () -> str
@@ -96,3 +110,11 @@ class FilterInserter(
             self._filter_mode = value
         else:
             raise TypeError("'filter_mode' must be a str or None")
+
+    # =========================================================================
+
+    def merge(self, other):
+        # type: (FilterInserter) -> None
+        super(FilterInserter, self).merge(other)
+
+        self.filter_mode = other.filter_mode
